pub enum CancelError {
NotFound(SessionId),
}Expand description
Error returned by crate::execution::ExecutionService::cancel.
cancel is idempotent for sessions already in a terminal state: calling
cancel on a Done, Failed, or already-Cancelled session returns Ok(()).
The only error is when the session does not exist at all.
Variants