pub enum ResumeOutcome {
Continued,
Terminal(TerminalOutcome),
}Expand description
Outcome returned by crate::execution::ExecutionService::resume.
Variants
Continued
The session accepted the response and is continuing execution.
Terminal(TerminalOutcome)
The session reached a terminal state after processing the response.