pub struct TokenCount {
pub tokens: u64,
pub source: TokenSource,
}Expand description
Accumulated token count with provenance.
Tracks both the total token count and the weakest TokenSource
across all accumulated calls. This lets consumers (e.g. alc_eval_compare)
know whether a comparison is between precise or estimated values.
Fields
tokens: u64source: TokenSourceTrait Implementations
Sourceimpl Clone for TokenCount
impl Clone for TokenCount
Sourcefn clone(&self) -> TokenCount
fn clone(&self) -> TokenCount
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for TokenCount
impl RefUnwindSafe for TokenCount
impl Send for TokenCount
impl Sync for TokenCount
impl Unpin for TokenCount
impl UnsafeUnpin for TokenCount
impl UnwindSafe for TokenCount